package com.ruoyi.os.mapper;

import java.util.List;
import com.ruoyi.os.domain.PatientInsuranceInfo;

/**
 * 患者医保信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-05-19
 */
public interface PatientInsuranceInfoMapper 
{
    /**
     * 查询患者医保信息
     * 
     * @param id 患者医保信息主键
     * @return 患者医保信息
     */
    public PatientInsuranceInfo selectPatientInsuranceInfoById(Long id);

    /**
     * 查询患者医保信息列表
     * 
     * @param patientInsuranceInfo 患者医保信息
     * @return 患者医保信息集合
     */
    public List<PatientInsuranceInfo> selectPatientInsuranceInfoList(PatientInsuranceInfo patientInsuranceInfo);

    /**
     * 新增患者医保信息
     * 
     * @param patientInsuranceInfo 患者医保信息
     * @return 结果
     */
    public int insertPatientInsuranceInfo(PatientInsuranceInfo patientInsuranceInfo);

    /**
     * 修改患者医保信息
     * 
     * @param patientInsuranceInfo 患者医保信息
     * @return 结果
     */
    public int updatePatientInsuranceInfo(PatientInsuranceInfo patientInsuranceInfo);

    /**
     * 删除患者医保信息
     * 
     * @param id 患者医保信息主键
     * @return 结果
     */
    public int deletePatientInsuranceInfoById(Long id);

    /**
     * 批量删除患者医保信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePatientInsuranceInfoByIds(Long[] ids);

    /**
     * Excel表批量插入患者医保信息
     *
     * @param insurancelist 患者医保信息集合
     * @return 结果
     */
    public int insertPatientInsuranceInfos (List<PatientInsuranceInfo> insurancelist);
}
